# SpDict

A commandline interface to spanishdict

## Installation

```
pip install spdict
```

## Usage

```
spdict --help
spdict translate chair desk table hola
spdict conjugate perder tomar
spdict conjugate subjunctive perder tomar
```
